@@ -379,7 +379,7 @@ class SPANDATA:
     Example: "MainThread"
     """
 
-    PROFILER_ID = "profiler.id"
+    PROFILER_ID = "profiler_id"
     """
     Label identifying the profiler id that the span occurred in. This should be a string.
     Example: "5249fbada8d5416482c2f6e47e337372"
@@ -529,4 +529,4 @@ DEFAULT_OPTIONS = _get_default_options()
 del _get_default_options
 
 
-VERSION = "2.7.1"
+VERSION = "2.8.0"
