@@ -115,7 +115,7 @@ if TYPE_CHECKING:
     ProfileContext = TypedDict(
         "ProfileContext",
         {
-            "profiler.id": str,
+            "profiler_id": str,
         },
     )
 
@@ -693,7 +693,7 @@ class Span:
             return None
 
         return {
-            "profiler.id": profiler_id,
+            "profiler_id": profiler_id,
         }
 
 
